==> lnl-2.1.10.tar.gz: lnl-2.1.10/src/tmenu_prot.h <==
/* tmenu.c */
void	init_tmenu( void );
char	*menu_shop_sel_mbr( shop_n_t shop_n );
char	*cb_menu_temple_init(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_temple_remove_curse(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_temple_cure_status(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_temple_resurrection(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_temple_contribution(
	menu_t **pp, menu_t **dflt
);
char	*menu_shop( shop_n_t shop_n, mbr_t *mbr, char *str_goto );
void	set_ls_menu_shop( long *k, deal_kind_t deal_kind );
char	*cb_menu_shop_data( menu_t **pp, menu_t **dflt );
char	*menu_town_mbr_data(
	mbr_data_edit_kind_t edit_kind,
	bool_t flg_ls_mbr
);
char	*cb_menu_shop_collect_gold(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_shop_divide_gold(
	menu_t **pp, menu_t **dflt
);
char	*cb_menu_shop( menu_t **pp, menu_t **dflt );
char	*cb_menu_shop_buy( menu_t **pp, menu_t **dflt );
char	*cb_menu_shop_sale_item( menu_t **pp, menu_t **dflt );
char	*cb_menu_shop_sale_equip( menu_t **pp, menu_t **dflt );
bool_t	menu_shop_buy(
	shop_n_t g_shop_n, mbr_t *g_sel_mbr, item_t *item
);
bool_t	menu_shop_sale_item(
	shop_n_t shop_n, mbr_t *mbr, item_t *item
);
bool_t	menu_shop_sale_equip(
	shop_n_t shop_n, mbr_t *mbr, item_t *item
);
bool_t	menu_shop_sale(
	shop_n_t shop_n, mbr_t *mbr, item_t *item,
	deal_kind_t deal_kind
);
item_t	*get_begin_article(
	mbr_t *mbr, shop_n_t shop_n, deal_kind_t kind
);
item_t	*get_next_article( item_t *art, deal_kind_t kind );
bool_t	chk_end_article( item_t *art, item_t *art_head, deal_kind_t kind );
bool_t	chk_deal_article(
	item_t *art, shop_n_t shop_n, deal_kind_t deal_kind
);
char	*menu_bar( void );
char	*cb_menu_bar_form( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_form_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_form_sub( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_form_sub_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_join( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_join_sub_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_join_sub( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_not_join( menu_t **pp, menu_t **dflt );
void	next_g_sel_ls_mbr( void );
char	*cb_menu_bar_edit_mbr( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_edit_mbr_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_edit_mbr_sub( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_data_form( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_data_edit( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_arrange( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_new_mbr( menu_t **pp, menu_t **dflt );
bool_t	exec_menu_new_mbr( void );
char	*cb_menu_bar_remove_mbr( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_remove_mbr_sub( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_edit_class( menu_t **pp, menu_t **dflt );
char	*menu_edit_class( long n );
char	*cb_menu_bar_new_class( menu_t **pp, menu_t **dflt );
char	*menu_new_class( long n );
long	exec_edit_class( class_t *org, bool_t flg_new );
char	*cb_menu_bar_remove_class( menu_t **pp, menu_t **dflt );
rate_t	calc_abl_total( class_t *p );
bool_t	exec_menu_ask_edit_class(
	class_t *org, class_t *work, bool_t flg_new
);
void	menu_edit_class_inc_abl(
	class_t *p, edit_class_t n, long add
);
char	*cb_menu_bar_save( menu_t **pp, menu_t **dflt );
char	*menu_inn( void );
char	*cb_menu_inn_stay( menu_t **pp, menu_t **dflt );

==> lnl-2.1.20.tar.gz: lnl-2.1.20/src/tmenu_prot.h <==
/* tmenu.c */
void	init_tmenu( void );
char	*menu_shop_sel_mbr( shop_n_t shop_n );
char	*cb_menu_temple_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_temple_remove_curse( menu_t **pp, menu_t **dflt );
char	*cb_menu_temple_cure_status( menu_t **pp, menu_t **dflt );
char	*cb_menu_temple_resurrection( menu_t **pp, menu_t **dflt );
char	*cb_menu_temple_contribution( menu_t **pp, menu_t **dflt );
char	*menu_restaurant( void );
bool_t	chk_shop_order( shop_n_t g_shop_n );
char	*menu_order( void );
char	*menu_order_sel_mbr( void );
char	*cb_menu_order_sel( menu_t **pp, menu_t **dflt );
char	*cb_menu_order_chose( menu_t **pp, menu_t **dflt );
bool_t	chk_order_milk( mbr_t *mbr, shop_n_t shop_n, item_t *item );
char	*menu_shop( shop_n_t shop_n, mbr_t *mbr, char *str_goto );
void	set_ls_menu_shop( long *k, deal_kind_t deal_kind );
char	*cb_menu_shop_data( menu_t **pp, menu_t **dflt );
char	*menu_town_mbr_data(
	mbr_data_edit_kind_t edit_kind,
	bool_t flg_ls_mbr
);
char	*cb_menu_shop_collect_gold( menu_t **pp, menu_t **dflt );
char	*cb_menu_shop_divide_gold( menu_t **pp, menu_t **dflt );
char	*cb_menu_shop( menu_t **pp, menu_t **dflt );
char	*cb_menu_shop_buy( menu_t **pp, menu_t **dflt );
char	*cb_menu_shop_sale_item( menu_t **pp, menu_t **dflt );
char	*cb_menu_shop_sale_equip( menu_t **pp, menu_t **dflt );
bool_t	menu_shop_buy(
	shop_n_t g_shop_n, mbr_t *g_sel_mbr, item_t *item
);
bool_t	menu_shop_sale_item(
	shop_n_t shop_n, mbr_t *mbr, item_t *item
);
bool_t	menu_shop_sale_equip(
	shop_n_t shop_n, mbr_t *mbr, item_t *item
);
bool_t	menu_shop_sale(
	shop_n_t shop_n, mbr_t *mbr, item_t *item,
	deal_kind_t deal_kind
);
item_t	*get_begin_article(
	mbr_t *mbr, shop_n_t shop_n, deal_kind_t kind
);
item_t	*get_next_article( item_t *art, deal_kind_t kind );
bool_t	chk_end_article( item_t *art, item_t *art_head, deal_kind_t kind );
bool_t	chk_deal_article(
	item_t *art, shop_n_t shop_n, deal_kind_t deal_kind
);
char	*menu_bar( void );
char	*cb_menu_bar_order( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_form( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_form_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_form_sub( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_form_sub_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_join( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_join_sub_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_join_sub( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_not_join( menu_t **pp, menu_t **dflt );
void	next_g_sel_ls_mbr( void );
char	*cb_menu_bar_edit_mbr( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_edit_mbr_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_edit_mbr_sub( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_data_form( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_data_edit( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_arrange( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_new_mbr( menu_t **pp, menu_t **dflt );
bool_t	exec_menu_new_mbr( void );
char	*cb_menu_bar_remove_mbr( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_remove_mbr_sub( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_edit_class( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_edit_class_sub( menu_t **pp, menu_t **dflt );
char	*menu_edit_class( long n );
char	*cb_menu_bar_arrange_class( menu_t **pp, menu_t **dflt );
char	*cb_menu_bar_new_class( menu_t **pp, menu_t **dflt );
char	*menu_new_class( long n );
long	exec_edit_class( class_t *org, bool_t flg_new );
char	*cb_menu_bar_remove_class( menu_t **pp, menu_t **dflt );
rate_t	calc_abl_total( class_t *p );
bool_t	exec_menu_ask_edit_class(
	class_t *org, class_t *work, bool_t flg_new
);
void	menu_edit_class_inc_abl(
	class_t *p, edit_class_t n, long add
);
char	*cb_menu_bar_save( menu_t **pp, menu_t **dflt );
char	*menu_inn( void );
char	*cb_menu_inn_stay( menu_t **pp, menu_t **dflt );
char	*cb_menu_magic_guild_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_magic_guild( menu_t **pp, menu_t **dflt );
char	*cb_menu_magic_guild_no_learn( menu_t **pp, menu_t **dflt );
char	*cb_menu_pet_shop_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_pet_shop_take( menu_t **pp, menu_t **dflt );
char	*cb_menu_pet_shop_take_sel( menu_t **pp, menu_t **dflt );
char	*cb_menu_pet_shop_leave( menu_t **pp, menu_t **dflt );
char	*cb_menu_pet_shop_leave_sel( menu_t **pp, menu_t **dflt );
char	*cb_menu_pet_shop_buy( menu_t **pp, menu_t **dflt );
char	*cb_menu_pet_shop_buy_sel( menu_t **pp, menu_t **dflt );
